@@ -228,7 +228,7 @@ public class MarkovChainBuilder implements NinaAction {
 	 */
 	@Override
 	public void setEdgeResource(NinaEvent q, NinaParser p, String s,
-			Map<String, String> map, Map<String, Object> sub) {
+			Map<String, String> map, NinaSubautomata sub) {
 		throw new NinaException("cannotaddnfa");
 	}
 
@@ -385,7 +385,7 @@ public class MarkovChainBuilder implements NinaAction {
 	 * @see net.morilib.nina.NinaAction#setEdgeSequence(net.morilib.nina.NinaEvent)
 	 */
 	@Override
-	public void setEdgeSequence(NinaEvent q, int len) {
+	public void setEdgeSequence(NinaEvent q, Range r, int len) {
 		throw new NinaException("isnotdfa");
 	}
 
@@ -397,4 +397,110 @@ public class MarkovChainBuilder implements NinaAction {
 		// do nothing
 	}
 
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setAccept(boolean)
+	 */
+	@Override
+	public void setAccept(boolean accept) {
+		vertex.accepted = accept;
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeDynamic(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeDynamic(NinaEvent q, String var) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#getDynamicTransitMap()
+	 */
+	@Override
+	public Map<String, String> getDynamicTransitMap() {
+		return Collections.emptyMap();
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeGrammar(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeGrammar(NinaEvent q, String name) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeRepeatedResource(net.morilib.nina.NinaEvent, java.lang.String, java.lang.Object)
+	 */
+	@Override
+	public void setEdgeRepeatedResource(NinaEvent q, String s,
+			Object d) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#empty(net.morilib.nina.NinaEvent, net.morilib.nina.NinaConsole)
+	 */
+	@Override
+	public NinaAction empty(NinaEvent q, String name) {
+		setStartState(createState(q));
+		return accept(name);
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeDigits(net.morilib.nina.NinaEvent)
+	 */
+	@Override
+	public void setEdgeDigits(NinaEvent q, int digits, boolean sign) {
+		throw new NinaException("isnotfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeHexadecimal(net.morilib.nina.NinaEvent, int)
+	 */
+	@Override
+	public void setEdgeHexadecimal(NinaEvent q, int bits) {
+		throw new NinaException("isnotfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeOctal(net.morilib.nina.NinaEvent, int)
+	 */
+	@Override
+	public void setEdgeOctal(NinaEvent q, int bits) {
+		throw new NinaException("isnotfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeFloat(net.morilib.nina.NinaEvent)
+	 */
+	@Override
+	public void setEdgeFloat(NinaEvent q) {
+		throw new NinaException("isnotfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeIndent(net.morilib.nina.NinaEvent, java.lang.String, int)
+	 */
+	@Override
+	public void setEdgeIndent(NinaEvent q, String cmp, int off) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeIdentifier(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeIdentifier(NinaEvent q, String lang) {
+		throw new NinaException("isnotfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeSkipSpaces(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeSkipSpaces(NinaEvent q, String str) {
+		throw new NinaException("isnotdfa");
+	}
+
 }
