@@ -25,8 +25,11 @@ import java.util.Set;
 import net.morilib.automata.NFA;
 import net.morilib.automata.NFAState;
 import net.morilib.automata.nfa.NFAAccept;
+import net.morilib.automata.nfa.NFAAlternative;
 import net.morilib.automata.nfa.NFAConcatenation;
 import net.morilib.automata.nfa.NFAObject;
+import net.morilib.automata.nfa.RegexParseException;
+import net.morilib.automata.nfa.RegexpParser;
 import net.morilib.automata.nfa.SingleObjectNFA;
 import net.morilib.range.Range;
 
@@ -130,12 +133,9 @@ public class NFABuilder implements NinaAction {
 		q.setEdge(o);
 	}
 
-	/* (non-Javadoc)
-	 * @see net.morilib.nina.NinaAction#setEdgeCharSequence(net.morilib.nina.NinaEvent, java.lang.CharSequence)
-	 */
-	@Override
-	public void setEdgeCharSequence(NinaEvent q, CharSequence s,
-			int qc) {
+	//
+	private NFAObject<Object, NFAState, Void> createQuoteNFA(
+			NinaEvent q, CharSequence s) {
 		List<NFAObject<Object, NFAState, Void>> l;
 		NFAObject<Object, NFAState, Void> o;
 		Integer c;
@@ -146,8 +146,35 @@ public class NFABuilder implements NinaAction {
 			o = SingleObjectNFA.newInstance((Object)c);
 			l.add(o);
 		}
-		o = NFAConcatenation.newInstance(l);
-		q.setEdge(NFAAccept.newInstance(o, null));
+		return NFAConcatenation.newInstance(l);
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeCharSequence(net.morilib.nina.NinaEvent, java.lang.CharSequence)
+	 */
+	@Override
+	public void setEdgeCharSequence(NinaEvent q, CharSequence s,
+			int qc) {
+		List<NFAObject<Object, NFAState, Void>> l;
+		NFAObject<Object, NFAState, Void> o;
+		List<DoubleQuoteTokenizer.Elems> b;
+		NFAState d;
+
+		if(qc == '"') {
+			l = new ArrayList<NFAObject<Object, NFAState, Void>>();
+			b = DoubleQuoteTokenizer.parse(s.toString());
+			for(DoubleQuoteTokenizer.Elems p : b) {
+				l.add(createQuoteNFA(q, p.getString()));
+			}
+			o = NFAAlternative.newInstance(l);
+		} else {
+			o = createQuoteNFA(q, s);
+		}
+
+		// state must not be null
+		// if accept state is null, optimizer will group different state
+		d = new NFAState() {};
+		q.setEdge(NFAAccept.newInstance(o, d));
 	}
 
 	/* (non-Javadoc)
@@ -158,9 +185,12 @@ public class NFABuilder implements NinaAction {
 			NinaParser p,
 			String s,
 			Map<String, String> map,
-			Map<String, Object> b) {
-		q.setEdge(p.compileSubautomaton(s, new NFABuilder(), map,
-				b).getMachine());
+			NinaSubautomata b) {
+		Object n;
+
+		n = p.compileSubautomaton(s, new NFABuilder(), map, b,
+				null).getMachine();
+		q.setEdge(n);
 	}
 
 	/* (non-Javadoc)
@@ -316,7 +346,7 @@ public class NFABuilder implements NinaAction {
 	 * @see net.morilib.nina.NinaAction#setEdgeSequence(net.morilib.nina.NinaEvent)
 	 */
 	@Override
-	public void setEdgeSequence(NinaEvent q, int len) {
+	public void setEdgeSequence(NinaEvent q, Range r, int len) {
 		throw new NinaException("isnotdfa");
 	}
 
@@ -328,4 +358,168 @@ public class NFABuilder implements NinaAction {
 		// do nothing
 	}
 
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setAccept(boolean)
+	 */
+	@Override
+	public void setAccept(boolean accept) {
+		if(accept) {
+			// accepted state
+			nfa.accept.put(vertex, null);
+		}
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeDynamic(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeDynamic(NinaEvent q, String var) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#getDynamicTransitMap()
+	 */
+	@Override
+	public Map<String, String> getDynamicTransitMap() {
+		return Collections.emptyMap();
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeGrammar(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeGrammar(NinaEvent q, String name) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeRepeatedResource(net.morilib.nina.NinaEvent, java.lang.String, java.lang.Object)
+	 */
+	@Override
+	public void setEdgeRepeatedResource(NinaEvent q, String s,
+			Object d) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#empty(net.morilib.nina.NinaEvent, net.morilib.nina.NinaConsole)
+	 */
+	@Override
+	public NinaAction empty(NinaEvent q, String name) {
+		setStartState(createState(q));
+		return accept(name);
+	}
+
+	//
+	private void _setRe(NinaEvent q, String re) {
+		NFA<Object, NFAState, Void> s;
+		NFAState d;
+
+		try {
+			// state must not be null
+			d = new NFAState() {};
+			s = RegexpParser.parse(re, d);
+			setEdge(q, s);
+		} catch(RegexParseException e) {
+			throw new NinaException("invalidregex");
+		}
+	}
+
+	@Override
+	public void setEdgeDigits(NinaEvent q, int digits, boolean sign) {
+		StringBuilder b = new StringBuilder();
+
+		if(sign) {
+			b.append("[-+]?");
+		}
+		if(digits < 0) {
+			b.append("[0-9]+");
+		} else {
+			b.append("[0-9]");
+			for(int i = 1; i < digits; i++) {
+				b.append("[0-9]?");
+			}
+		}
+		_setRe(q, b.toString());
+//		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeHexadecimal(net.morilib.nina.NinaEvent, int)
+	 */
+	@Override
+	public void setEdgeHexadecimal(NinaEvent q, int bits) {
+		StringBuilder b = new StringBuilder();
+
+		if(bits < 0) {
+			b.append("[0-9A-Fa-f]+");
+		} else {
+			b.append("[0-9A-Fa-f]");
+			for(int i = 8; i < bits; i++) {
+				b.append("[0-9A-Fa-f]?");
+			}
+		}
+		_setRe(q, b.toString());
+//		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeOctal(net.morilib.nina.NinaEvent, int)
+	 */
+	@Override
+	public void setEdgeOctal(NinaEvent q, int bits) {
+		switch(bits) {
+		case 8:
+			_setRe(q, "([0-3][0-7]?|[4-7])[0-7]?");
+			break;
+		case 16:
+			_setRe(q, "([0-1][0-7]?|[2-7])[0-7]?[0-7]?[0-7]?[0-7]?");
+			break;
+		case 32:
+			_setRe(q, "([0-3][0-7]?|[4-7])" +
+					"[0-7]?[0-7]?[0-7]?[0-7]?[0-7]?[0-7]?[0-7]?[0-7]?[0-7]?");
+			break;
+		default:
+			_setRe(q, "[0-7]+");
+			break;
+		}
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeFloat(net.morilib.nina.NinaEvent)
+	 */
+	@Override
+	public void setEdgeFloat(NinaEvent q) {
+		_setRe(q, "[-+]?([0-9]+|[0-9]*.[0-9]+)([eE][-+]?[0-9]+)?");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeIndent(net.morilib.nina.NinaEvent, java.lang.String, int)
+	 */
+	@Override
+	public void setEdgeIndent(NinaEvent q, String cmp, int off) {
+		throw new NinaException("isnotdfa");
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeIdentifier(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeIdentifier(NinaEvent q, String lang) {
+		if(lang.equals("Java")) {
+			_setRe(q, "[A-Za-z_$\\u0080-\\ufffc][A-Za-z0-9_$\\u0080-\\ufffc]*");
+		} else {
+			_setRe(q, "[A-Za-z_][A-Za-z0-9_]*");
+		}
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaAction#setEdgeSkipSpaces(net.morilib.nina.NinaEvent, java.lang.String)
+	 */
+	@Override
+	public void setEdgeSkipSpaces(NinaEvent q, String str) {
+		throw new NinaException("isnotdfa");
+	}
+
 }
