@@ -46,16 +46,36 @@ public final class Nina {
 	/**
 	 * 
 	 */
-	public static final String VERSION = "0.4.9";
+	public static final String VERSION = "0.4.10";
+
+	/**
+	 * 
+	 */
+	public static final String REVISION = "$Rev: 432 $";
 
 	//
 	private static final Pattern FANM = Pattern.compile(
 			"(.*/)?([^/.]+)(\\..*)?");
 	private static final Pattern CDLM = Pattern.compile("-+");
+	private static final Pattern REVS = Pattern.compile("[0-9]+");
 
 	//
 	private Nina() {}
 
+	/**
+	 * 
+	 * @return
+	 */
+	public static String getRevision() {
+		Matcher m;
+
+		if((m = REVS.matcher(REVISION)).find()) {
+			return m.group();
+		} else {
+			return "0";
+		}
+	}
+
 	//
 	static Object prendClasse(String s) {
 		return prendClasse("", s);
@@ -154,11 +174,13 @@ public final class Nina {
 	}
 
 	//
-	static int len(char c) {
+	static int len(char c, boolean notfull) {
 		Character.UnicodeBlock b;
 
 		b = Character.UnicodeBlock.of(c);
-		if(b == null) {
+		if(notfull) {
+			return 1;
+		} else if(b == null) {
 			return 1;
 		} else if(c >= 0xff01 && c <= 0xff60) {
 			return 2;
@@ -183,22 +205,22 @@ public final class Nina {
 		}
 	}
 
-	static int len(String s) {
+	static int len(String s, boolean notfull) {
 		int r = 0;
 
 		for(int i = 0; i < s.length(); i++) {
-			r = r + len(s.charAt(i));
+			r = r + len(s.charAt(i), notfull);
 		}
 		return r;
 	}
 
-	static int[] toiarray(String s) {
+	static int[] toiarray(String s, boolean notfull) {
 		int[] a;
 		int m;
 
-		a = new int[len(s)];
+		a = new int[len(s, notfull)];
 		for(int i = 0, j = 0; j < s.length(); i += m, j++) {
-			m = len(s.charAt(j));
+			m = len(s.charAt(j), notfull);
 			a[i] = s.charAt(j);
 			for(int k = i + 1; k < i + m; k++) {
 				a[k] = Quadro.EQ_TO_LEFT;
@@ -261,7 +283,7 @@ public final class Nina {
 	}
 
 	static List<int[]> readImport(String fn, List<String> lb,
-			String enc) throws IOException {
+			String enc, boolean notfull) throws IOException {
 		BufferedReader r = null;
 		boolean b = false;
 		List<int[]> l;
@@ -284,7 +306,7 @@ public final class Nina {
 				if(b) {
 					b = !CDLM.matcher(s).matches();
 				} else if(!(b = CDLM.matcher(s).matches())){
-					l.add(toiarray(s));
+					l.add(toiarray(s, notfull));
 				}
 			}
 			return l;
