@@ -84,4 +84,17 @@ public interface NinaEvent {
 	 */
 	public String getName();
 
+	/**
+	 * 
+	 * @return
+	 */
+	public NinaLanguageOption getLanguageOption();
+
+	/**
+	 * 
+	 * @param t
+	 * @return
+	 */
+	public boolean isGrammar(String t);
+
 }
