@@ -74,11 +74,12 @@ public class NinaParser {
 		FRSE,  FRSE2, FR_W,  FRSW,  FRSW2, FR_N,
 		AR_N,  AR_E,  AREN0, AREN1, AR_EQ, AR_Eq, ARED1, ARED2,
 		AR_ER, ARER1, ARER2, ARER3, ARER4,
-		AR_EI, AR_Ei, AR_EG, AR_Eg, AR_ES, AR_EM, AR_EX, AREE1, AREE2,
+		AR_EI, AR_Ei, AR_EG, AR_Eg, AR_ES, AR_EM, AR_EX, AR_EW,
+		AREE1, AREE2,
 		AR_S,  AR_W,  ARWN0, ARWN1, ARWN2, AR_WQ,
 		AR_Wq, AR_Wy, AR_Wn, AR_Wr, AR_Wt, AR_W0, ARWD1, ARWD2,
 		AR_WR, ARWR1, ARWR2, ARWR3, ARWR4, ARWR5,
-		AR_WI, AR_Wi, ARWi2, AR_WG, AR_Wg, AR_WS, AR_WM, AR_WX,
+		AR_WI, AR_Wi, ARWi2, AR_WG, AR_Wg, AR_WS, AR_WM, AR_WX, AR_WW,
 		AR_ZN, AR_ZS, AR_ZE, AR_ZW,
 		F2_W,  F2_N,  F3_W,  F3_N,
 		BR_N,  BR_E,  BR_S,  BR_W,
@@ -1837,6 +1838,11 @@ public class NinaParser {
 				q.east();
 				buf = new StringBuffer();
 				etat = S.AREE1;
+			} else if(q.get() == '~') {
+				q.set(Quadro.W2);
+				q.east();
+				buf = new StringBuffer();
+				etat = S.AR_EW;
 			} else if(q.get() == '0') {
 				buf = new StringBuffer();
 				q.set(Quadro.W2);
@@ -2209,6 +2215,23 @@ public class NinaParser {
 				throw new NinaException(this, "invalidmealy");
 			}
 			break;
+		case AR_EW:
+			if(q.get() == '~') {
+				action.setEdgeSkipSpaces(q, buf.toString());
+				q.set(Quadro.W2);
+				q.east();
+				etat = S.AR_ES;
+			} else if(q.get() >= 0) {
+				buf.append((char)q.get());
+				q.set(Quadro.W2);
+				q.east();
+			} else if(q.get() == Quadro.EQ_TO_LEFT) {
+				q.set(Quadro.W2);
+				q.east();
+			} else {
+				throw new NinaException(this, "invalidmealy");
+			}
+			break;
 		case WP_E1:
 			if(q.get() == ')') {
 				q.set(Quadro.WARP2);
@@ -2375,6 +2398,11 @@ public class NinaParser {
 				q.set(Quadro.E2);
 				q.west();
 				etat = S.AR_WS;
+			} else if(q.get() == '~') {
+				q.set(Quadro.E2);
+				q.west();
+				buf = new StringBuffer();
+				etat = S.AR_WW;
 			} else if(q.get() >= '0' && q.get() <= '9') {
 				buf = new StringBuffer().append((char)q.get());
 				q.set(Quadro.E2);
@@ -2915,6 +2943,12 @@ public class NinaParser {
 				q.west();
 				buf = new StringBuffer();
 				etat = S.WP_W1;
+			} else if(q.get() == '~') {
+				metmealy();
+				q.set(Quadro.E2);
+				q.west();
+				etat = S.AR_WW;
+				buf = new StringBuffer();
 			} else if(q.get() == '.') {
 				metmealy();
 				q.setEdge(CharSets.ALL_CHAR);
@@ -2953,6 +2987,23 @@ public class NinaParser {
 				throw new NinaException(this, "invalidmealy");
 			}
 			break;
+		case AR_WW:
+			if(q.get() == '~') {
+				action.setEdgeSkipSpaces(q, buf.reverse().toString());
+				q.set(Quadro.E2);
+				q.west();
+				etat = S.AR_W;
+			} else if(q.get() >= 0) {
+				buf.append((char)q.get());
+				q.set(Quadro.E2);
+				q.west();
+			} else if(q.get() == Quadro.EQ_TO_LEFT) {
+				q.set(Quadro.E2);
+				q.west();
+			} else {
+				throw new NinaException(this, "invalidmealy");
+			}
+			break;
 		case WP_W1:
 			if(q.get() == '(') {
 				buf.reverse();
