@@ -54,6 +54,7 @@ public class Quadro implements NinaEvent {
 	//
 	private static final String LOPT = "targetLanguage";
 	private static final String EOG = "-- end of grammar --";
+	private static final String ALLBYTE1 = "#notfullwidth";
 	private static final Pattern PTN1 = Pattern.compile(
 			"--[ \t]+(.+)[ \t]+--");
 	private static final Pattern PTN2 = Pattern.compile("%.*\\{");
@@ -964,8 +965,8 @@ public class Quadro implements NinaEvent {
 		List<String[]> d = new ArrayList<String[]>();
 		BufferedReader br = new BufferedReader(rd);
 		List<String> sl = new ArrayList<String>();
+		boolean b = false, b2 = true, nf = false;
 		String s, x = null, desc = "";
-		boolean b = false, b2 = true;
 		StringWriter sw = null;
 		PrintWriter pw = null;
 		int y = 0, p = 0;
@@ -994,6 +995,8 @@ public class Quadro implements NinaEvent {
 				}
 			} else if(s.equals("")) {
 				continue;
+			} else if(ALLBYTE1.equals(s)) {
+				nf = true;
 			} else if(CDLM.matcher(s).matches()) {
 				b2 = false;
 				sw = new StringWriter();
@@ -1003,7 +1006,7 @@ public class Quadro implements NinaEvent {
 				y = p + 1;
 				x = h.group(1);
 				l = new ArrayList<int[]>();
-				for(String t : sl)  l.add(Nina.toiarray(t));
+				for(String t : sl)  l.add(Nina.toiarray(t, nf));
 			} else if((h = PTN3.matcher(s)).matches()) {
 				z = setquadro(q, m, x, y, z, l);
 				x = h.group(1);
@@ -1013,7 +1016,8 @@ public class Quadro implements NinaEvent {
 				z = setquadro(q, m, x, y, z, l);
 				a = Nina.readHeader(h.group(1), libs);
 				putquadro(q, h.group(2),
-						Nina.readImport(h.group(1), libs, a[2]), m, y);
+						Nina.readImport(h.group(1), libs, a[2], nf),
+						m, y);
 				if(a[0] != null)  d.add(a);
 				x = null;
 			} else if((h = PTN5.matcher(s)).matches()) {
@@ -1026,15 +1030,15 @@ public class Quadro implements NinaEvent {
 				continue;
 			} else if(!b && z == null && s.charAt(0) == '#') {
 				sl.add(s);
-				l.add(Nina.toiarray(s));
+				l.add(Nina.toiarray(s, nf));
 			} else if(!b && PTN2.matcher(s).lookingAt()) {
 				b = true;
-				l.add(Nina.toiarray(s));
+				l.add(Nina.toiarray(s, nf));
 			} else if(b && s.startsWith("%}")) {
 				b = false;
-				l.add(Nina.toiarray(s));
+				l.add(Nina.toiarray(s, nf));
 			} else {
-				l.add(Nina.toiarray(s));
+				l.add(Nina.toiarray(s, nf));
 			}
 		}
 
