@@ -33,6 +33,7 @@ import net.morilib.nina.Quadro;
 import net.morilib.nina.TMBuilder;
 import net.morilib.nina.translate.sh.ReplaceStrangeChar;
 import net.morilib.range.Interval;
+import net.morilib.range.Range;
 import net.morilib.sh.ShEnvironment;
 
 /**
@@ -67,6 +68,14 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		return o == Interval.FROM_INFIMUM ? 0 : ((Integer)o).intValue();
 	}
 
+	//
+	private int infimumbound(Range a) {
+		Interval v;
+
+		v = a.intervals().first();
+		return infimumbound(v);
+	}
+
 	//
 	private int getDeadStateNo() {
 		Object s;
@@ -95,6 +104,8 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 			x = "'\\''";
 		} else if(Character.isISOControl(c)) {
 			x = Integer.toString(c);
+		} else if(c >= 0x80) {
+			x = Integer.toString(c);
 		} else if(c < Character.MAX_VALUE) {
 			x = String.format("'%c'", (char)c);
 		} else {
@@ -109,14 +120,13 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 	}
 
 	//
-	private void printintv(PrintStream out, Interval v, boolean els,
+	private void printintv1(PrintStream out, Interval v, boolean els,
 			Object o) {
-		String s, t, a, x, y, z;
+		String s, t, x, y, z;
 		int c, d;
 
 		s = v.isInfimumClosed() ? ">=" : ">";
 		t = v.isSupremumClosed() ? "<=" : "<";
-		a = els ? "\t\t} else if" : "\t\tif";
 		c = ((Integer)v.getInfimumBound()).intValue();
 		d = ((Integer)v.getSupremumBound()).intValue();
 		x = tostr(c);
@@ -124,13 +134,28 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		z = o != null && o.toString().startsWith(LOK) ?
 				"__l__ && " : "";
 		if(v.isClosed() && c == d) {
-			out.format("%s(%s__c__ == %s) {\n", a, z, x);
+			out.format("(%s__c__ == %s)", z, x);
 		} else {
-			out.format("%s(%s__c__ %s %s && __c__ %s %s) {\n",
-					a, z, s, x, t, y);
+			out.format("(%s__c__ %s %s && __c__ %s %s)", z, s, x, t,
+					y);
 		}
 	}
 
+	//
+	private void printintv(PrintStream out, Range r, boolean els,
+			Object o) {
+		String a, d = "";
+
+		a = els ? "\t\t} else if" : "\t\tif";
+		out.format("%s(", a);
+		for(Interval v : r.intervals()) {
+			out.print(d);
+			printintv1(out, v, els, o);
+			d = " || ";
+		}
+		out.format(") {\n");
+	}
+
 	//
 	private String outln(boolean els, PrintStream out, String s) {
 		if(els) {
@@ -217,8 +242,9 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 	//
 	private void printState(PrintStream out,
 			DFAState<Object, ?, Void> dfa) {
-		boolean els = false;
 		int sn = getStateNo(dfa), c;
+		Map<Object, Range> z;
+		boolean els = false;
 		DFABuilder.DBS a, b;
 		TMBuilder.DBS x;
 		Set<String> k;
@@ -236,8 +262,11 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 			return;
 		}
 
+		// classify edges
+		z = classifyEdges(dfa);
+
 		// with lookahead
-		for(Interval v : dfa.getAlphabetRanges()) {
+		for(Range v : z.values()) {
 			if(v.isEmpty())  continue;
 			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
@@ -250,7 +279,7 @@ public class NinaTranslatorC extends AbstractNinaTranslator {
 		}
 
 		// without lookahead
-		for(Interval v : dfa.getAlphabetRanges()) {
+		for(Range v : z.values()) {
 			if(v.isEmpty())  continue;
 			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
