@@ -33,6 +33,7 @@ import net.morilib.nina.Quadro;
 import net.morilib.nina.TMBuilder;
 import net.morilib.nina.translate.sh.ReplaceStrangeChar;
 import net.morilib.range.Interval;
+import net.morilib.range.Range;
 import net.morilib.sh.ShEnvironment;
 
 /**
@@ -68,6 +69,14 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 		return o == Interval.FROM_INFIMUM ? 0 : ((Integer)o).intValue();
 	}
 
+	//
+	private int infimumbound(Range a) {
+		Interval v;
+
+		v = a.intervals().first();
+		return infimumbound(v);
+	}
+
 	//
 	private String tostr(int c) {
 		String x;
@@ -80,6 +89,8 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 			x = "'\\''";
 		} else if(Character.isISOControl(c)) {
 			x = Integer.toString(c);
+		} else if(c >= 0x80) {
+			x = Integer.toString(c);
 		} else if(c < Character.MAX_VALUE) {
 			x = String.format("'%c'", (char)c);
 		} else {
@@ -94,27 +105,40 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 	}
 
 	//
-	private void printintv(PrintStream out, Interval v, boolean els,
+	private void printintv1(PrintStream out, Interval v, boolean els,
 			Object o) {
-		String s, t, a, x, y, z;
+		String s, t, x, y, z;
 		int c, d;
 
 		s = v.isInfimumClosed() ? ">=" : ">";
 		t = v.isSupremumClosed() ? "<=" : "<";
-		a = els ? "\t\t\t} else if" : "\t\t\tif";
 		c = ((Integer)v.getInfimumBound()).intValue();
 		d = ((Integer)v.getSupremumBound()).intValue();
 		x = tostr(c);
 		y = tostr(d);
 		z = isLookahead(o) ? "__l__ && " : "";
 		if(v.isClosed() && c == d) {
-			out.format("%s(%s$c == %s) {\n", a, z, x);
+			out.format("(%s$c == %s)", z, x);
 		} else {
-			out.format("%s(%s$c %s %s && $c %s %s) {\n",
-					a, z, s, x, t, y);
+			out.format("(%s$c %s %s && $c %s %s)", z, s, x, t, y);
 		}
 	}
 
+	//
+	private void printintv(PrintStream out, Range r, boolean els,
+			Object o) {
+		String a, d = "";
+
+		a = els ? "\t\t\t} else if" : "\t\t\tif";
+		out.format("%s(", a);
+		for(Interval v : r.intervals()) {
+			out.print(d);
+			printintv1(out, v, els, o);
+			d = " || ";
+		}
+		out.format(") {\n");
+	}
+
 	//
 	private void printobj(PrintStream out, Object o, boolean els,
 			Object m) {
@@ -327,7 +351,7 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 	}
 
 	//
-	private void checkRange(Map<Interval, Object> r, Interval v,
+	private void checkRange(Map<Interval, Object> r, Range v,
 			Object m) {
 		for(Map.Entry<Interval, Object> t : r.entrySet()) {
 			if(!t.getKey().independentOf(v) &&
@@ -335,7 +359,10 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 				options.pwarn("nondeterministic", v.toString());
 			}
 		}
-		r.put(v, m);
+
+		for(Interval z : v.intervals()) {
+			r.put(z, m);
+		}
 	}
 
 	//
@@ -416,6 +443,7 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 			DFAState<Object, ?, Void> dfa) {
 		Map<Interval, Object> r = new HashMap<Interval, Object>();
 		int sn = getStateNo(dfa), c;
+		Map<Object, Range> z;
 		int[] a = new int[1];
 		boolean els = false;
 		Object o;
@@ -429,8 +457,11 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 			return;
 		}
 
+		// classify edges
+		z = classifyEdges(dfa);
+
 		// with lookahead
-		for(Interval v : dfa.getAlphabetRanges()) {
+		for(Range v : z.values()) {
 			if(v.isEmpty())  continue;
 			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
@@ -444,7 +475,7 @@ public class NinaTranslatorJava extends AbstractNinaTranslator {
 		}
 
 		// without lookahead
-		for(Interval v : dfa.getAlphabetRanges()) {
+		for(Range v : z.values()) {
 			if(v.isEmpty())  continue;
 			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
