@@ -32,6 +32,7 @@ import net.morilib.nina.Quadro;
 import net.morilib.nina.TMBuilder;
 import net.morilib.nina.translate.sh.ReplaceStrangeChar;
 import net.morilib.range.Interval;
+import net.morilib.range.Range;
 import net.morilib.sh.ShEnvironment;
 
 /**
@@ -67,6 +68,14 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 		return o == Interval.FROM_INFIMUM ? 0 : ((Integer)o).intValue();
 	}
 
+	//
+	private int infimumbound(Range a) {
+		Interval v;
+
+		v = a.intervals().first();
+		return infimumbound(v);
+	}
+
 	//
 	private String tostr(int c) {
 		return Integer.toString(c);
@@ -78,14 +87,13 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 	}
 
 	//
-	private void printintv(PrintStream out, Interval v, boolean els,
+	private void printintv1(PrintStream out, Interval v, boolean els,
 			Object o) {
-		String s, t, a, x, y, z;
+		String s, t, x, y, z;
 		int c, d;
 
 		s = v.isInfimumClosed() ? ">=" : ">";
 		t = v.isSupremumClosed() ? "<=" : "<";
-		a = els ? "\t\t\t} else if" : "\t\tif";
 		c = ((Integer)v.getInfimumBound()).intValue();
 		d = ((Integer)v.getSupremumBound()).intValue();
 		x = tostr(c);
@@ -93,13 +101,27 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 		z = o != null && o.toString().startsWith(LOK) ?
 				"__l__ && " : "";
 		if(v.isClosed() && c == d) {
-			out.format("%s(%s$c == %s) {\n", a, z, x);
+			out.format("(%s$c == %s)", z, x);
 		} else {
-			out.format("%s(%s$c %s %s && $c %s %s) {\n",
-					a, z, s, x, t, y);
+			out.format("(%s$c %s %s && $c %s %s)", z, s, x, t, y);
 		}
 	}
 
+	//
+	private void printintv(PrintStream out, Range r, boolean els,
+			Object o) {
+		String a, d = "";
+
+		a = els ? "\t\t\t} else if" : "\t\tif";
+		out.format("%s(", a);
+		for(Interval v : r.intervals()) {
+			out.print(d);
+			printintv1(out, v, els, o);
+			d = " || ";
+		}
+		out.format(") {\n");
+	}
+
 	//
 	private void printobj(PrintStream out, Object o, boolean els,
 			Object m) {
@@ -366,8 +388,9 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 	//
 	private void printState(PrintStream out,
 			DFAState<Object, ?, Void> dfa) {
-		boolean els = false;
 		int sn = getStateNo(dfa), c;
+		Map<Object, Range> z;
+		boolean els = false;
 		Object o;
 
 		out.format("\tcase %d:\n", sn);
@@ -381,8 +404,11 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 			return;
 		}
 
+		// classify edges
+		z = classifyEdges(dfa);
+
 		// with lookahead
-		for(Interval v : dfa.getAlphabetRanges()) {
+		for(Range v : z.values()) {
 			if(v.isEmpty())  continue;
 			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
@@ -395,7 +421,7 @@ public class NinaTranslatorJavaScript extends AbstractNinaTranslator {
 		}
 
 		// without lookahead
-		for(Interval v : dfa.getAlphabetRanges()) {
+		for(Range v : z.values()) {
 			if(v.isEmpty())  continue;
 			c = infimumbound(v);
 			if(v.isInfimumOpen())  c++;
