@@ -1,3 +1,4 @@
+#! /bin/jsh
 #
 # Copyright 2013-2014 Yuichiro Moriguchi
 #
@@ -46,6 +47,7 @@ cat << EOF
 public $ABSTRACT class ${CLASSNAME}${TEMPLATE} $cln $EXTENDS $IMPLEMENTS
 {
 
+	/* @@@-PARSER-CODE-START-@@@ */
 	class TokenException : System.Exception
 	{
 	}
@@ -54,6 +56,8 @@ public $ABSTRACT class ${CLASSNAME}${TEMPLATE} $cln $EXTENDS $IMPLEMENTS
 	{
 		int Step($streamsym __rd, $CTYPE c) $tre;
 		bool Accepted();
+		bool Dead();
+		bool EmptyTransition();
 		int Execaction($CTYPE c);
 		bool Isend();
 		int Recover(System.Exception e);
@@ -102,6 +106,7 @@ cat << EOF
 	private const int NinaStacklen = 72;
 	private const int NinaDiscardstate = 0x40000000;
 	const int INITIAL = 0;
+	const int INDENT = 1;
 
 	private int STATE;
 	private int[] __sts = new int[NinaStacklen];
@@ -116,6 +121,11 @@ cat << EOF
 	$streamsym befstream = null;
 	System.Exception exception;
 
+	System.Text.StringBuilder _buffer;
+	int _int;
+	object _bigint;
+	object _num;
+
 	void _initlist() {
 		_l = new System.Collections.Generic.List<$VALTYPE>();
 	}
@@ -125,6 +135,15 @@ cat << EOF
 	}
 
 EOF
+
+[ -n "$ENABLE_INDENT" ] && cat << EOF
+	private int _indent;
+	private int _indentBefore;
+	private bool __is_line_begin = true;
+	private int __indent_unread = -1;
+
+EOF
+
 [ -z "$NEWLINEMODE" ] && echo "	private $CTYPE binunread = $nullsym;"
 for i in $SUBAUTOMATA
 do
@@ -171,29 +190,98 @@ then
 fi
 
 cat field
-[ -n "$LEXER" ] && echo "private $LCTYPE _unreadl = $nullsyml;"
+[ -n "$LEXER" ] && echo "	private $LCTYPE _unreadl = $nullsyml;"
+[ -n "$LEXER" ] || echo "	private $CTYPE _unreadl = $nullsym;"
 echo
 
 function _putreadf {
-echo "	$2 $1($streamsym stream)"
-echo "	{"
-if [ -s read ]; then
-  cat read
-elif [ -z "$3" ]; then
-  cat << EOF
+  [ -n "$ENABLE_INDENT" ] || echo "	$2 $1($streamsym stream)"
+  [ -n "$ENABLE_INDENT" ] && echo "	$2 ${1}_1($streamsym stream)"
+  echo '	{'
+  if [ -s read ]; then
+    cat read
+  elif [ -z "$3" ]; then
+    cat << EOF
 		int c;
 
 		c = stream.${readfn}();
 		return c < 0 ? NinaEOF : c;
 EOF
-else
-  echo "		return ($2)stream.next();"
-fi
-echo '	}'
+  else
+    echo "		return ($2)stream.next();"
+  fi
+  echo '	}'
+
+  if [ -n "$ENABLE_INDENT" ]; then
+    cat << EOF
+	$2 $1($streamsym stream)
+	{
+		int c;
+
+		if(__indent_unread >= 0)
+		{
+			c = __indent_unread;
+			__indent_unread = -1;
+		}
+		else if(!__is_line_begin)
+		{
+			c = ${1}_1(stream);
+		}
+		else
+		{
+			_indent = 0;
+			while((c = ${1}_1(stream)) == ' ' || c == '\t')
+			{
+				_indent++;
+			}
+			__indent_unread = c;
+			c = c >= 0 ? INDENT : c;
+		}
+
+		if(__is_line_begin = c == '\n')
+		{
+			_indentBefore = _indent;
+		}
+		return c;
+	}
+EOF
+  fi
 }
 
 if [ -z "$LEXER" ]; then
-  _putreadf _Read1 "$CTYPE" "$TYPE"
+  _putreadf _Read1l "$CTYPE" "$TYPE"
+  cat << EOF
+
+	$CTYPE _Read1($streamsym stream)
+	{
+		$CTYPE c;
+
+		if(_unreadl != $nullsym)
+		{
+			c = _unreadl;
+			_unreadl = $nullsym;
+		}
+EOF
+  if [ -z "$TYPE" -a -z "$NEWLINEMODE" ]; then
+    cat <<  EOF
+		else if((c = _Read1l(stream)) == '\r' && (c = _Read1l(stream)) != '\n')
+		{
+			_unreadl = c;
+			c = '\r';
+		}
+EOF
+  else
+    cat << EOF
+		else
+		{
+			c = _Read1l(stream);
+		}
+EOF
+  fi
+  cat << EOF
+		return c;
+	}
+EOF
 else
   _putreadf _Read1l "$LCTYPE" "$LTYPE"
   nina_template.nfa.cs.sub2.sh "$LEXER" "$LCTYPE" "$LTYPE" "$LEXER" "$LCTYPE"
@@ -239,9 +327,14 @@ EOF
 
 		s = STATE;  STATE = 0;
 		f = ${LEXER}_Accepted();
-		while(o == null && (a = _Read1ul(stream)) != $nullsyml)
+		while(o == null)
 		{
-			if(${LEXER}_Step(a) == 0)
+			if((a = _Read1ul(stream)) == $nullsyml)
+			{
+				o = ${LEXER}_Gettoken(b);
+				break;
+			}
+			else if(${LEXER}_Step(a) == 0)
 			{
 				if(f)
 				{
@@ -471,6 +564,13 @@ then
 	{
 		$CTYPE[] a;
 
+		if(__lookahead_ptr > 0)
+		{
+			a = new $CTYPE[__lookahead.Length - __lookahead_ptr];
+			System.Array.Copy(__lookahead, __lookahead_ptr, a, 0, a.Length);
+			__lookahead = a;
+		}
+
 		if(__lookahead == null)
 		{
 			a = new $CTYPE[__lookaheadw_ptr];
@@ -728,6 +828,20 @@ EOF
     cat << EOF
 		}
 
+		public bool Dead()
+		{
+EOF
+    print_deads $i
+    cat << EOF
+		}
+
+		public bool EmptyTransition()
+		{
+EOF
+    print_empty_transitions $i
+    cat << EOF
+		}
+
 		public override string ToString()
 		{
 			return "${ch1}";
@@ -812,6 +926,16 @@ c='$c'
 			return true;
 		}
 
+		public bool Dead()
+		{
+			return false;
+		}
+
+		public bool EmptyTransition()
+		{
+			return false;
+		}
+
 		public int Execaction($CTYPE c)
 		{
 			return 1;
@@ -998,7 +1122,45 @@ EOF
 					UNGET(c);
 					st = NinaFail;  return $nullsym;
 				}
-				c = _Read(rd);
+
+				if(__stk[__slen - 1].EmptyTransition()) {
+					// do nothing
+				}
+				else if(!__stk[__slen - 1].Dead()) {
+					c = _Read(rd);
+				}
+				else if(b)
+				{
+					__Logprint("accept " + __stk[__slen - 1]);
+					st = NinaAccept;  return $nullsym;
+EOF
+  [ -n "$ENABLE_LOOKAHEAD" ] && cat << EOF
+				}
+				else if(__lookaheadw_ptr >= 0)
+				{
+					__Logprint("match failed: try lookahead: ", c);
+					LOOKAHEAD_RB();
+					b = en.Accepted();
+EOF
+  [ -n "$ENABLE_BACKTRACK" ] && cat << EOF
+				}
+				else if(BACKTRACK(c))
+				{
+					__Logprint("match failed: try backtracking: ", c);
+EOF
+  cat << EOF
+				}
+				else if(c == $nullsym)
+				{
+					if(!b)  throw new ${TOKENERROR}();
+					st = NinaAccept;  return $nullsym;
+				}
+				else
+				{
+					__Logprint("match failed: ", c);
+					__Puttrace();
+					st = NinaFail;  return $nullsym;
+				}
 			} while(true);
 		} catch(System.Exception e) {
 			UNGET(c);
@@ -1170,6 +1332,11 @@ EOF
 		return o.Parse(rd);
 	}
 
+	static void puts(string s)
+	{
+		System.Console.WriteLine(s);
+	}
+
 EOF
 
 [ -z "$TYPE" -o -z "$LTYPE" ] && [ -z "$NEWLINEMODE" ] && cat << EOF
@@ -1189,7 +1356,30 @@ for i in $SUBAUTOMATA
 do
   print_constants $i
 done
+echo '	/* @@@-PARSER-CODE-END-@@@ */'
 
 cat fragment
 #cat fragment | replace_action
+
+[ -n "$PUTMAIN" ] && cat << EOF
+	static void Main() {
+		ParseAll(System.Console.In);
+	}
+EOF
+[ -n "$PUTPROMPT" ] && cat << EOF
+	static void Main() {
+		string s;
+
+		System.Console.Write("> ");
+		while((s = System.Console.ReadLine()) != null) {
+			try {
+				ParseAll(new System.IO.StringReader(s));
+				System.Console.Write("> ");
+			} catch(System.Exception) {
+				System.Console.WriteLine("syntax error");
+			}
+		}
+	}
+EOF
+
 echo '}'
